# ==================================================================
# Plugins::DirectoryDepth - Auto Generated Install Module
#
#   Plugins::DirectoryDepth
#   Author  : Ian McGregor
#   Version : 1.0.3
#
# Thanks for the help Paul, Ivan (Yogi) and others!
# This is my very first plugin, so if you use, use at your own risk, if you improve it, share your improvements 
# with me, please.
# Note: while the cateogry form will show you the Depth field... it won't allow you to change the value 
# manually. This is a precaution to prevent editors from altering category depth values.
#
# ==================================================================
#

package Plugins::DirectoryDepth;
# ==================================================================
    use strict;
    use vars  qw/$VERSION $DEBUG $NAME $META/;
    use GT::Base;
    use GT::Plugins qw/STOP CONTINUE/;
    use Links qw/$CFG $IN $DB/;

    $VERSION = '1.0.3';
    $DEBUG   = 0;
    $NAME    = 'DirectoryDepth';
# Inhert from base class for debug and error methods
    @Plugins::DirectoryDepth::ISA = qw(GT::Base);

    $META = {
    'author' => 'Ian McGregor',
    'url' => 'http://www.iuni.com',
    'license' => 'Freeware',
    'description' => 'Plugin to add Directory Depth functionality and statistics to Links SQL.',
    'prog_ver' => '2.1.0',
    'version' => '1.0.3'
};


sub pre_install {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they install
# the plugin.
#
    my $inst_msg = 'This plugin will add a column \'Depth\' to the category table. It will update this column when a category 

is added, or moved.';
    $inst_msg .= "<br>Thanks for the help Paul, Ivan (Yogi), Webmaster and others who helped me write my 1st plugin!";

    return $inst_msg;
}

sub pre_uninstall {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they remove the
# plugin.
#
    my $uninst_msg = 'This will uninstall the Directory Depth plugin.';

    return $uninst_msg;
}

sub install {
# -------------------------------------------------------------------
# This function does the actual installation. It's first argument is
# a plugin manager which you can use to register hooks, install files,
# add menu options, etc. The second argument is a GT::Tar object which
# you can use to access any files in your plugin module.
#
# You should return an HTML formatted string that will be displayed 
# to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::DirectoryDepth::error
#
    my ($mgr, $tar) = @_;
    
    $mgr->install_hooks ( 'DirectoryDepth', [ ['add_category', 'PRE', 'Plugins::DirectoryDepth::add_category', 'FIRST'] ]);
    $mgr->install_hooks ( 'DirectoryDepth', [ ['move_category', 'PRE', 'Plugins::DirectoryDepth::move_category', 'FIRST'] ]);
    $mgr->install_hooks ( 'DirectoryDepth', [ ['modify_category', 'PRE', 'Plugins::DirectoryDepth::modify_category', 'FIRST'] 

]);
    $mgr->install_menu ( 'DirectoryDepth', [ ['repair', 'admin.cgi?do=plugin&plugin=DirectoryDepth&func=repair'] ] );
    $mgr->install_menu ( 'DirectoryDepth', [ ['stats', 'admin.cgi?do=plugin&plugin=DirectoryDepth&func=stats'] ] );
    unless (exists $DB->table('Category')->cols->{'Depth'})  {
	my $editor = $DB->editor ('Category'); 
	unless (
		$editor->add_col ('Depth', { 
		form_display => 'Category Depth', 
		form_size => '2', 
		form_type => 'INT', 
		not_null => '0', 
		default => '0' ,
		type => 'INT' })
	
	) 

	
	{
		$Plugins::DirectoryDepth::error = "Unable to add column to Links: $GT::SQL::error";
		return;
	}
};
    return "The plugin has been successfully installed!";
}

sub uninstall {
# -------------------------------------------------------------------
# This function removes the plugin. It's first argument is
# also a plugin manager which you can use to register hooks, install files,
# add menu options, etc. You should return an HTML formatted string
# that will be displayed to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::DirectoryDepth::error
#
    my $mgr = shift;
    
    $mgr->uninstall_hooks ( 'DirectoryDepth', [ ['add_category', 'PRE', 'Plugins::DirectoryDepth::add_category', 'FIRST'] ]);
    $mgr->uninstall_hooks ( 'DirectoryDepth', [ ['move_category', 'PRE', 'Plugins::DirectoryDepth::move_category', 'FIRST'] 

]);
    $mgr->uninstall_menu ( 'DirectoryDepth', [ ['repair', 'admin.cgi?do=plugin&plugin=DirectoryDepth&func=repair'] ] );
    $mgr->uninstall_menu ( 'DirectoryDepth', [ ['stats', 'admin.cgi?do=plugin&plugin=DirectoryDepth&func=stats'] ] );
    ;
    
    # remove 'Depth' column from 'Cateogry'
    my $editor = $DB->editor('Category');
    $editor->drop_col ('Depth');

    return "The plugin has been successfully removed!";
}

1;
